@@ -1,9 +1,9 @@
 package RestTest::Controller::API::REST::Track;
+our $VERSION = '2.001001';
+use Moose;
+BEGIN { extends 'Catalyst::Controller::DBIC::API::REST' }
 
-use strict;
-use warnings;
-use base qw/Catalyst::Controller::DBIC::API::REST/;
-use JSON::Syck;
+use namespace::autoclean;
 
 __PACKAGE__->config
     ( action => { setup => { PathPart => 'track', Chained => '/api/rest/rest_base' } },
