@@ -1,10 +1,11 @@
 package # hide from PAUSE
     RestTest::Schema;
+our $VERSION = '2.001001';
 
 use base qw/DBIx::Class::Schema/;
 
 no warnings qw/qw/;
 
-__PACKAGE__->load_classes(qw/Artist CD Track Tag Producer CD_to_Producer/);
+__PACKAGE__->load_namespaces;
 
 1;
