@@ -1,8 +1,10 @@
 package # hide from PAUSE 
     RestTest::Schema::Result::Artist;
+our $VERSION = '2.001001';
 
-use base 'DBIx::Class::Core';
+use base 'DBIx::Class';
 
+__PACKAGE__->load_components('Core');
 __PACKAGE__->table('artist');
 __PACKAGE__->add_columns(
   'artistid' => {
